dodgr_components: Identify connected components of graph.

dodgr_componentsR Documentation

Identify connected components of graph.

Description

Identify connected components of graph and add corresponding component column to data.frame.

Usage

dodgr_components(graph, strong = FALSE)

Arguments

graph

A data.frame of edges

strong

Defaults to ⁠FALSE', which may identify components which can only be accessed from a single direction, and therefore not actually used in routing calculations. If ⁠TRUE', all edges in each identified component are fully connected in both directions.

Value

Equivalent graph with additional component column, sequentially numbered from 1 = largest component.

See Also

Other modification: dodgr_contract_graph(), dodgr_uncontract_graph()

Examples

graph <- weight_streetnet (hampi)
graph <- dodgr_components (graph)

dodgr documentation built on Sept. 3, 2026, 5:08 p.m.