dodgr_deduplicate_graph: Deduplicate edges in a graph

dodgr_deduplicate_graphR Documentation

Deduplicate edges in a graph

Description

Graph may have duplicated edges, particularly when extracted as dodgr_streetnet objects. This function de-duplicates any repeated edges, reducing weighted distances and times to the minimal values from all duplicates.

Usage

dodgr_deduplicate_graph(graph)

Arguments

graph

Any 'dodgr' graph or network.

Value

A potentially modified version of graph, with any formerly duplicated edges reduces to single rows containing minimal weighted distances and times.

See Also

Other conversion: dodgr_to_igraph(), dodgr_to_sf(), dodgr_to_sfc(), dodgr_to_tidygraph(), igraph_to_dodgr()

Examples

net0 <- weight_streetnet (hampi, wt_profile = "foot")
nrow (net0)
# Duplicate part of input data:
h2 <- rbind (hampi, hampi [1, ])
net1 <- weight_streetnet (h2, wt_profile = "foot")
nrow (net1) # network then has more edges
net2 <- dodgr_deduplicate_graph (net1)
nrow (net2)
stopifnot (identical (nrow (net0), nrow (net2)))

dodgr documentation built on Sept. 3, 2026, 5:08 p.m.