Learn R Programming

dodgr (version 0.1.1)

weighting_profiles: weighting_profiles

Description

Collection of weighting profiles used to adjust the routing process to different means of transport. Original data taken from the Routino project.

Arguments

Format

data.frame with profile names, means of transport and weights.

References

https://www.routino.org/xml/routino-profiles.xml