- graph
data.frame or equivalent object representing the network
graph (see Details)
- from
Vector or matrix of points from which aggregate flows are to
be calculated (see Details)
- to
Vector or matrix of points to which aggregate flows are to be
calculated (see Details)
- k
Width of exponential spatial interaction function (exp (-d / k)),
in units of 'd', specified in one of 3 forms: (i) a single value; (ii) a
vector of independent values for each origin point (with same length as
'from' points); or (iii) an equivalent matrix with each column holding values
for each 'from' point, so 'nrow(k)==length(from)'. See Note.
- dens_from
Vector of densities at origin ('from') points
- dens_to
Vector of densities at destination ('to') points
- contract
If TRUE (default), calculate flows on contracted graph
before mapping them back on to the original full graph (recommended as this
will generally be much faster). FALSE should only be used if the graph
has already been contracted.
- norm_sums
Standardise sums from all origin points, so sum of flows
throughout entire network equals sum of densities from all origins (see
Note).
- heap
Type of heap to use in priority queue. Options include
Fibonacci Heap (default; FHeap), Binary Heap (BHeap),
Trinomial Heap (TriHeap), Extended Trinomial Heap
(TriHeapExt, and 2-3 Heap (Heap23).
- tol
Relative tolerance below which flows towards to vertices are not
considered. This will generally have no effect, but can provide speed gains
when flow matrices represent spatial interaction models, in which case this
parameter effectively reduces the radius from each from point over which
flows are aggregated. To remove any such effect, set tol = 0.
- quiet
If FALSE, display progress messages on screen.