LINESTRING objects to POLYGON objects representing all
fundamental cycles within the LINESTRING objects.Convert sf LINESTRING objects to POLYGON objects representing all
fundamental cycles within the LINESTRING objects.
dodgr_sflines_to_poly(sflines, graph_max_size = 10000, expand = 0.05)An sf::sfc collection of POLYGON objects.
An sf LINESTRING object representing a network.
Maximum size submitted to the internal C++ routines as a single chunk. Warning: Increasing this may lead to computer meltdown!
For large graphs which must be broken into chunks, this factor determines the relative overlap between chunks to ensure all cycles are captured. (This value should only need to be modified in special cases.)
Other misc:
compare_heaps(),
dodgr_flowmap(),
dodgr_full_cycles(),
dodgr_fundamental_cycles(),
dodgr_insert_vertex(),
dodgr_sample(),
dodgr_vertices(),
merge_directed_graph(),
summary.dodgr_dists_categorical(),
write_dodgr_wt_profile()