| dodgr_streetnet_geodesic | R Documentation |
Distances by default are Mapbox "cheap" distances if maximal network distances are < 100km, otherwise Haversine distances. Calling this function forces all calls to weight_streetnet from that point on to use geodesic distances. These are more computationally expensive to calculate, and weighting networks will likely take more time.
dodgr_streetnet_geodesic(unset = FALSE)
unset |
Calling this function with |
Nothing; the function is called for its side-effect only of setting distance calculations to geodesic.
Other extraction:
dodgr_streetnet(),
dodgr_streetnet_sc(),
weight_railway(),
weight_streetnet()
net0 <- weight_streetnet (hampi) # Default "cheap" method
dodgr_streetnet_geodesic ()
net1 <- weight_streetnet (hampi)
cor (net0$d, net1$d) # Strongly correlated, but not perfect
max (abs (net0$d - net1$d)) # in metres
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.