Learn R Programming

dodgr (version 0.4.0)

dodgr_uncontract_graph: Re-expand a contracted graph.

Description

Revert a contracted graph created with dodgr_contract_graph back to the full, uncontracted version. This function is mostly used for the side effect of mapping any new columns inserted on to the contracted graph back on to the original graph, as demonstrated in the example.

Usage

dodgr_uncontract_graph(graph)

Value

A single data.frame representing the equivalent original, uncontracted graph.

Arguments

graph

A contracted graph created from dodgr_contract_graph.

See Also

Other modification: dodgr_components(), dodgr_contract_graph()

Examples

Run this code
graph0 <- weight_streetnet (hampi)
nrow (graph0) # 6,813
graph1 <- dodgr_contract_graph (graph0)
nrow (graph1) # 760
graph2 <- dodgr_uncontract_graph (graph1)
nrow (graph2) # 6,813

# Insert new data on to the contracted graph and uncontract it:
graph1$new_col <- runif (nrow (graph1))
graph3 <- dodgr_uncontract_graph (graph1)
# graph3 is then the uncontracted graph which includes "new_col" as well
dim (graph0)
dim (graph3)

Run the code above in your browser using DataLab