powered by
Collection of weighting profiles used to adjust the routing process to different means of transport. Original data taken from the Routino project.
data.frame with profile names, means of transport and weights.
data.frame
https://www.routino.org/xml/routino-profiles.xml